<?php

/**
 * Adds a border to image
 *
 * @param $image
 *   An image object. The $image->resource value will be modified by this call.
 * @param $hex
 *   The color used for the border.
 * @param $top
 *   Margin top.
 * @param $right
 *   Margin right.
 * @param $bottom
 *   Margin bottom.
 * @param $left
 *   Margin left.
 */
function image_imagick_border(stdClass $image, $hex, $top, $right, $bottom, $left) {
  $color = new Imagick();
  $width = $image->info['width'] + $left + $right;
  $height = $image->info['height'] + $top + $bottom;
  $color->newImage($width, $height, $hex);

  $color->compositeImage($image->resource, Imagick::COMPOSITE_DEFAULT, $left, $top);

  $image->resource = $color;

  $image->info['width'] = $width;
  $image->info['height'] = $height;
  return TRUE;
}

/**
 * Adds a border effect.
 *
 * @param $image
 *   An image object
 * @param array $data
 *   The data passed from the form
 */
function imagick_border($image, $data = array()) {
  image_toolkit_invoke('border', $image, $data);
}

/**
 * Settings form for the border effect.
 *
 * @param $action
 *   The saved action form parameters.
 */
function imagick_border_form($action) {
  $default = array(
    'HEX' => '#E2DB6A',
    'top' => 10,
    'right' => 10,
    'bottom' => 10,
    'left' => 10,
  );
  $action = array_merge($default, (array) $action);

  $form = array(
    '#prefix' => '<div class="colorform" >',
    '#suffix' => '</div>',
  );

  $form['colorpicker'] = array(
    '#weight' => -1,
    '#markup' => '<div class="colorpicker" style="float:right;"></div>',
  );
  $form['HEX'] = array(
    '#type' => 'textfield',
    '#title' => t('HEX'),
    '#default_value' => $action['HEX'],
    '#size' => 7,
    '#element_validate' => array('imagecache_rgb_validate'),
    '#attributes' => array('class' => array('colorentry')),
  );

  // Adds the JS that binds the textarea with the farbtastic element.

  // Find each colorpicker placeholder:
  // initialize it,
  // then find the nearby textfield that is of type colorentry
  // and attach the colorpicker behavior to it.
  // This is so we can support more that one per page if neccessary.
  $init_colorpicker_script = "
    (function ($) {
      Drupal.behaviors.attachcolorpicker = {
        attach: function(context) {
          $('.colorpicker').each(function () {
            // Configure picker to be attached to the nearest colorentry field.
            linked_target = $('.colorentry', $(this).closest('.colorform'))
            farb = $.farbtastic($(this), linked_target);
          });
        }
      }
    })(jQuery);
  ";

  // Add Farbtastic color picker.
  $form['HEX']['#attached'] = array(
    'library' => array(
      array('system', 'farbtastic'),
    ),
    'js' => array(
      array(
        'type' => 'inline',
        'data' => $init_colorpicker_script,
      ),
    ),
  );
  $form['top'] = array(
    '#type' => 'textfield',
    '#title' => t('Padding top'),
    '#default_value' => $action['top'],
  );
  $form['right'] = array(
    '#type' => 'textfield',
    '#title' => t('Padding right'),
    '#default_value' => $action['right'],
  );
  $form['bottom'] = array(
    '#type' => 'textfield',
    '#title' => t('Padding bottom'),
    '#default_value' => $action['bottom'],
  );
  $form['left'] = array(
    '#type' => 'textfield',
    '#title' => t('Padding left'),
    '#default_value' => $action['left'],
  );

  return $form;
}
